--[[
Top Parses on Boss Tooltip
Configuration Page
]]--

local _, addon = ...;

-- UI
TPBTConf = {}
--local ACD = LibStub("MSA-AceConfigDialog-3.0")


-- Saved Variables
TPBTConfig = {	
	["Important"] = false,
	--["PriorityTargets"] = false,
	--["Defensives"] = false,
	--["Interrupts"] = false,
	--["Fluff"] = false,
	--["Advanced"] = false,
	["ClassChoice"] = "Show my class only",
	["ShowFrame"] = "Show mouseover",
	["TargetTrigger"] = "Show targeted mob",
	["FrameWidth"] = 450,
	["FrameHeight"] = 175,
	["FontSize"] = 12,
	["FrameOpacity"] = 0.55
}

-- Create Checkboxes
local function createCheck(label, description, frame, onClick)
	local check = CreateFrame("CheckButton", "TPBTCheck" .. label, frame, "InterfaceOptionsCheckButtonTemplate")
	check:SetScript("OnClick", function(self)
		onClick(self)
	end)
	
	getglobal(check:GetName() .. 'Text'):SetText(description)
	
	return check
	
end


local function createString(frame, text, font, size)
	local fontString = frame:CreateFontString()
	fontString:SetFont(font, size)
	fontString:SetText(text)
	fontString:SetWidth(215)
	fontString:SetJustifyH("LEFT")
	fontString:SetJustifyV("TOP")
	
	return fontString
end

local function updateTextSize(size)
	local p,_,_ = TPBT_ParseText:GetFont();
	--print("Resetting Font Size" .. TPBTConfig.FontSize)
	TPBT_ParseText:SetFont(p, TPBTConfig.FontSize, nil)

end


--[[
function createDropdown(frame, label, option1, option2, changingVar)

	local dd = CreateFrame("Frame", label, frame, "UIDropDownMenuTemplate")
	
	local function dd_OnClick(self, arg1, arg2, checked)
		UIDropDownMenu_SetText(dd, arg1)
		TPBTConfig[changingVar] = arg1
		setEnabled() -- This just clears the addons frame.
		setDropdownEnabled() -- This shows / hides a second dropdown based on the current selection.
	end
	
	function ddMenu(frame, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.func = dd_OnClick
		info.text, info.arg1, info.checked = option1, option1, TPBTConfig[changingVar] == option1
		UIDropDownMenu_AddButton(info)
		info.text, info.arg1, info.checked = option2, option2, TPBTConfig[changingVar] == option2
		UIDropDownMenu_AddButton(info)
	
	end
		
	UIDropDownMenu_Initialize(dd, ddMenu)
	UIDropDownMenu_SetWidth(dd, 180, 0);
	
	return dd
end
]]--

-- Create Panels
local function createConfigMenu()

	-- Setup Panel --
	addon.configPanel = CreateFrame("Frame", "TPBTConfiguration", UIParent)
	addon.configPanel.name = "Top Parses on Boss Tooltip";
	addon.configPanel.okay = function (self) return end
	addon.configPanel.cancel = function (self) return end
	
	-- Set up Title --
	local ddTitleString = addon.configPanel:CreateFontString()
	ddTitleString:SetPoint("TOPLEFT", 10, -10)
	ddTitleString:SetFont("Fonts\\MORPHEUS.ttf", 22, "OUTLINE")
	ddTitleString:SetTextColor(0.9, 0.68, 0.22, 1)
	ddTitleString:SetText("Top Parses on Boss Tooltip Config")

	
	-----------------------
	-- Set up Checkboxes --
	-----------------------
	--local chkGeneral = createCheck("General", "Show top DPS / HPS", addon.configPanel, function(self, value) end)
	--chkGeneral:SetPoint("TOPLEFT", ddTitleString, "BOTTOMLEFT", 0, -10)
	--chkGeneral:SetEnabled(false)
	--chkGeneral:SetChecked(true)
	
	--local chkPriority = createCheck("PriorityTargets", "Show Priority Targets", addon.configPanel, function(self, value) TPBTConfig.PriorityTargets = self:GetChecked() end)
	--chkPriority:SetPoint("TOPLEFT", chkGeneral, "BOTTOMLEFT", 0, -8)
	
	--local chkInterrupts = createCheck("Interrupts", "Show Priority Interrupts", addon.configPanel, function(self, value) TPBTConfig.Interrupts = self:GetChecked() end)
	--chkInterrupts:SetPoint("TOPLEFT", chkPriority, "BOTTOMLEFT", 0, -8)
	
	--local chkDefensives = createCheck("Defensives", "Show Defensive Recommendations", addon.configPanel, function(self, value) TPBTConfig.Defensives = self:GetChecked() end)
	--chkDefensives:SetPoint("TOPLEFT", chkInterrupts, "BOTTOMLEFT", 0, -8)
	
	--local chkFluff = createCheck("Fluff", "Show Fluff", addon.configPanel, function(self, value) TPBTConfig.Fluff = self:GetChecked() end)
	--chkFluff:SetPoint("TOPLEFT", chkDefensives, "BOTTOMLEFT", 0, -8)
	
	--local chkAdvanced = createCheck("Advanced", "Show advanced tips", addon.configPanel, function(self, value) TPBTConfig.Advanced = self:GetChecked() end)
	--chkAdvanced:SetPoint("TOPLEFT", chkFluff, "BOTTOMLEFT", 0, -8)
	
	
	----------------------------
	-- Setup "Dropdown" boxes --
	----------------------------
	-- Dropdown
	local headerFont = "Fonts\\MORPHEUS.ttf"
	local headerSize = 16
	
	-- Parse Location Selector --
	local locFS = createString(addon.configPanel, "Parse Location", headerFont, headerSize)
	locFS:SetPoint("TOPLEFT", ddTitleString, "BOTTOMLEFT", 0, -8)
	
	--locDD = createDropdown(addon.configPanel, "TipLocation", "Show in separate frame", "Show in mob tooltips", "ShowFrame")
	--locDD:SetPoint("TOPLEFT", locFS, "BOTTOMLEFT", 0, -8)
	local locCB = createCheck("Location", "Show parses in separate frame", addon.configPanel, 
			function(self, value)
				if self:GetChecked() then
					TPBTConfig.ShowFrame = "Show in separate frame"
				else
					TPBTConfig.ShowFrame = "Show in mob tooltips"
				end
				addon:setEnabled() -- This just clears the addons frame.
				--addon:setMinimized(true) -- Ensures the tip frame is showing.
				addon:setDropdownEnabled() -- This shows / hides a second dropdown based on the current selection.
			end)
	locCB.tooltip = "Uncheck to have parses appear in mob tooltips instead"
	locCB:SetPoint("TOPLEFT", locFS, "BOTTOMLEFT", 0, -8)
	
	-- Target / Mouseover Selector --
	addon.targetFS = createString(addon.configPanel, "Show Target or Mouseover", headerFont, headerSize)
	addon.targetFS:SetPoint("TOPLEFT", locFS, "TOPRIGHT", 70, 0)
	
	--targetDD = createDropdown(addon.configPanel, "TargetMouseover", "Show targeted mob", "Show mouseover", "TargetTrigger")
	--targetDD:SetPoint("TOPLEFT", targetFS, "BOTTOMLEFT", 0, -8)
	addon.chkTarget = createCheck("Target", "Show Targeted Mob", addon.configPanel, 
			function(self, value)
				if self:GetChecked() then
					TPBTConfig.TargetTrigger = "Show targeted mob"
				else
					TPBTConfig.TargetTrigger = "Show mouseover"
				end
			end)
	addon.chkTarget:SetPoint("TOPLEFT", addon.targetFS, "BOTTOMLEFT", 0, -8)
	
	-- Class Selector --
	local classFS = createString(addon.configPanel, "Class Specific Parses", headerFont, headerSize)
	classFS:SetPoint("TOPLEFT", locCB, "BOTTOMLEFT", 0, -14)
	
	--classDD = createDropdown(addon.configPanel, "ClassSelector", "Show my class only", "Show all classes", "ClassChoice")
	--classDD:SetPoint("TOPLEFT", classFS, "BOTTOMLEFT", 0, -8)
	local chkClass = createCheck("Class", "Show all classes", addon.configPanel, 
			function(self, value)
				if self:GetChecked() then
					TPBTConfig.ClassChoice = "Show all classes"
				else
					TPBTConfig.ClassChoice = "Show my class only"
				end
			end)	
	chkClass:SetPoint("TOPLEFT", classFS, "BOTTOMLEFT", 0, -8)

	-- Other Stuff
	local OtherFS = createString(addon.configPanel, "Font Size", headerFont, headerSize)
	OtherFS:SetPoint("TOPLEFT", classFS, "BOTTOMLEFT", 0, -54)
	
	--local deleteme = createString(addon.configPanel, "Delete me after", headerFont, headerSize)
	--deleteme:SetPoint("TOPLEFT", OtherFS, "BOTTOMLEFT", 0, -16)
	
	local sliderName = "FontSizeS"
	local fontEdit = CreateFrame("Slider", sliderName, addon.configPanel, "OptionsSliderTemplate")
	
	fontEdit:SetWidth(120)
	fontEdit:SetHeight(20)
	fontEdit:SetOrientation('HORIZONTAL')
	fontEdit:SetMinMaxValues(8, 14)
	fontEdit:SetValue(TPBTConfig.FontSize)
	fontEdit:SetValueStep(1)
	
	fontEdit.textLow = _G[sliderName.."Low"]
	fontEdit.textHigh = _G[sliderName.."High"]
	fontEdit.text = _G[sliderName.."Text"]
	fontEdit.minValue, fontEdit.maxValue = fontEdit:GetMinMaxValues() 
	fontEdit.textLow:SetText(fontEdit.minValue)
	fontEdit.textHigh:SetText(fontEdit.maxValue)
	fontEdit.text:SetText(TPBTConfig.FontSize)
	
	fontEdit.textLow = 8
	fontEdit.textHigh = 14
	--fontEdit.text = "Font Size"
	
	
	fontEdit:SetPoint("TOPLEFT", OtherFS, "BOTTOMLEFT", 0, -22)
	fontEdit:Enable()
	fontEdit:SetScript("OnValueChanged", function(self,event,arg1) 
		
		TPBTConfig.FontSize = math.floor(event + 0.5)
		updateTextSize()
		--print(TPBTConfig.FontSize)
		self.text:SetText(TPBTConfig.FontSize)
			end)
	
	--[[
	
	
	
	local fontEdit = CreateFrame("EditBox", nil, addon.configPanel)
	fontEdit:SetMultiLine(false)
	fontEdit:SetWidth(40)
	fontEdit:SetText(12)
	fontEdit:SetFontObject(ChatFontNormal)
	fontEdit:SetPoint("TOPLEFT", OtherFS, "BOTTOMLEFT", 0, -8)
	fontEdit:SetEnabled(true) ]]--
	--chkRegDungeons:SetChecked(true)
	
	
	
	-- Load in SavedVariables on ADDON_LOADED
	addon.configPanel:RegisterEvent("ADDON_LOADED")
	addon.configPanel:SetScript("OnEvent", function(self, event, arg1)
		if event == "ADDON_LOADED" then
			-- Check for new variables added in a later release
			TPBTConfig.ShowFrame = TPBTConfig.ShowFrame or "Show in separate frame"
			TPBTConfig.TargetTrigger = TPBTConfig.TargetTrigger or "Show targeted mob"
			
			-- More variables added in a later release
			if TPBTConfig.RaidToggle == nil then TPBTConfig.RaidToggle = true end
			if TPBTConfig.MythicPlusToggle == nil then TPBTConfig.MythicPlusToggle = true end
			TPBTConfig.FrameOpacity = TPBTConfig.FrameOpacity or 0.55
			TPBTConfig.FrameWidth = TPBTConfig.FrameWidth or 450
			TPBTConfig.FrameHeight = TPBTConfig.FrameHeight or 175
			TPBTConfig.FontSize = TPBTConfig.FontSize or 14
			--print(TPBTConfig.FontSize)
			
			-- Set default checkbox behaviour
			--chkPriority:SetChecked(TPBTConfig.PriorityTargets)
			--chkInterrupts:SetChecked(TPBTConfig.Interrupts)
			--chkDefensives:SetChecked(TPBTConfig.Defensives)
			--chkFluff:SetChecked(TPBTConfig.Fluff)
			--chkAdvanced:SetChecked(TPBTConfig.Advanced)
			--chkMythicPlus:SetChecked(TPBTConfig.MythicPlusToggle)
			
			--chkRaid:SetChecked(TPBTConfig.RaidToggle)
			
			-- Set default Drop Down text
			--UIDropDownMenu_SetText(locDD, TPBTConfig.ShowFrame)
			--UIDropDownMenu_SetText(targetDD, TPBTConfig.TargetTrigger)
			--UIDropDownMenu_SetText(classDD, TPBTConfig.ClassChoice)
			-- "Drop downs"
			locCB:SetChecked(TPBTConfig.ShowFrame == "Show in separate frame")
			addon.chkTarget:SetChecked(TPBTConfig.TargetTrigger == "Show targeted mob")		

			chkClass:SetChecked(TPBTConfig.ClassChoice == "Show all classes")
			
			updateTextSize()
			fontEdit.text:SetText(TPBTConfig.FontSize)
			fontEdit:SetValue(TPBTConfig.FontSize)
			
			addon:setEnabled()
			addon:setDropdownEnabled()
		end
	end);
	
	-- Add panel to config options
	InterfaceOptions_AddCategory(addon.configPanel)
	
	-- Proceed
	createTPBTFrame()
end

createConfigMenu()

